@@ -145,8 +145,10 @@ class Queue(object):
         """Select if run using SLURM script."""
         f = open(filename, "w")
         f.write("%s\n" % shell)
-        f.write("#SBATCH --nodes=%d\n" % (nnodes))
-        f.write("#SBATCH --ntasks-per-node=%d\n" % (cores))
+        if nnodes is not None:
+            f.write("#SBATCH --nodes=%d\n" % (nnodes))
+        if cores is not None:
+            f.write("#SBATCH --ntasks-per-node=%d\n" % (cores))
 
         if walltime is not None:
             if isinstance(walltime, str):
