@@ -1,5 +1,12 @@
-from jarvis.ai.descriptors.get_desc import CFID
+from jarvis.ai.descriptors.cfid import CFID
+from jarvis.ai.descriptors.coulomb import coulomb_matrix
+from jarvis.ai.descriptors.elemental import get_element_fraction_desc
 from jarvis.core.atoms import Atoms
+from jarvis.ai.descriptors.cfid import get_chem_only_descriptor
+
+
+def test_formula_only():
+    desc, names = get_chem_only_descriptor("Al2O3")
 
 
 def test_desc():
@@ -3137,6 +3144,10 @@ def test_desc():
         cfid_names,
         [round(i, 2) for i in cfid_values],
     )
+    z = coulomb_matrix(Si)
+    assert len(z) == 100
+    assert round(z[0], 2) == round(281.62894609, 2)
+    get_element_fraction_desc()
 
 
 # test_desc()
